@@ -1,5 +1,5 @@
 #!/bin/sh
-# @(#) $Id: jpegrotate.sh 270 2015-07-05 02:02:49Z leres $ (XSE)
+# @(#) $Id: jpegrotate.sh 284 2016-08-29 22:23:32Z leres $ (XSE)
 #
 # jpegrotate - rotate jpeg images
 #
@@ -35,22 +35,22 @@ for a do
 	case "${a}" in
 
 	-l)
-		option="-rotate 270"
+		option="-2"
 		shift
 		;;
 
 	-r)
-		option="-rotate 90"
+		option="-9"
 		shift
 		;;
 
 	-f)
-		option="-rotate 180"
+		option="-1"
 		shift
 		;;
 
 	-h)
-		option="-flip horizontal"
+		option="-F"
 		shift
 		;;
 
@@ -60,7 +60,7 @@ for a do
 		;;
 
 	-v)
-		option="-flip vertical"
+		option="-f"
 		shift
 		;;
 
@@ -92,7 +92,7 @@ if [ ! -x ${touch} ]; then
 	touch="touch"
 fi
 
-# Execute (or echo if -n)
+# Execute (or just echo if -n)
 execute() {
 	cmd="$*"
 	if [ ${dryrun} -eq 0 ]; then
@@ -147,7 +147,7 @@ if [ ${undo} -ne 0 ]; then
 fi
 
 # Make sure we have everything we need
-for f in exiftags jhead jpegtran; do
+for f in exiftags exiftran; do
 	which ${f} > /dev/null 2>&1
 	if [ $? -ne 0 ]; then
 		echo "${prog}: Can't find ${f}" 1>&2
@@ -264,26 +264,15 @@ while [ $# -gt 0 ]; do
 	# Transform
 	if [ -z "${option}" ]; then
 		# Automatic
-		execute "jhead -q -autorot ${r}"
-		if [ $? -ne 0 ]; then
-			rm ${r}
-			exit 1
-		fi
-	else
-		# Manual
-		execute "jpegtran -copy all ${option} ${f} > ${r}"
-		if [ $? -ne 0 ]; then
-			rm ${r}
-			exit 1
-		fi
-		execute "jhead -q -norot ${r}"
-		if [ $? -ne 0 ]; then
-			rm ${r}
-			exit 1
-		fi
+		option="-a"
+	fi
+	execute "exiftran ${option} -o ${r} ${f}"
+	if [ $? -ne 0 ]; then
+		rm ${r}
+		exit 1
 	fi
 
-	# Do this last in case jhead/jpegtran fails
+	# Do this last in case exiftran fails
 	execute "mv ${f} ${o}"
 
 	# Copy access and modified timestamps
